Subject: [bug#67464] [PATCH gnome-team v2 4/4] gnu: mutter: Update to 45.1.

From: Vivien Kraus <[email-masked]>
Date: Sun, 26 Nov 2023 16:06:21 +0100

* gnu/packages/gnome.scm (mutter): Update to 45.1.
[#:configure-flags]: Update runpath override to /lib/mutter-13.
[propagated-inputs]: Update comments.
[inputs]: Add libei.

Change-Id: I7e7e14560f5ece106f4adb838d28cf2ae91ca3c5
---
 gnu/packages/gnome.scm | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 416db8e6f6..4875103feb 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -7789,7 +7789,7 @@ (define-public zenity
 (define-public mutter
   (package
     (name "mutter")
-    (version "44.6")
+    (version "45.1")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnome/sources/" name "/"
@@ -7797,7 +7797,7 @@ (define-public mutter
                                   name "-" version ".tar.xz"))
               (sha256
                (base32
-                "0qlnjmq83g2bbkvigsaj7qw8gxbij4w37fpg1vywg43zcc1s2s7c"))))
+                "0b11vacpkarahbrh7pd4nhsynbxb3ad8ic8w65wnrdrdnbpwblrc"))))
     ;; NOTE: Since version 3.21.x, mutter now bundles and exports forked
     ;; versions of cogl and clutter.  As a result, many of the inputs,
     ;; propagated-inputs, and configure flags used in cogl and clutter are
@@ -7814,7 +7814,7 @@ (define-public mutter
          ;; Otherwise, the RUNPATH will lack the final path component.
          (string-append "-Dc_link_args=-Wl,-rpath="
                         #$output "/lib,-rpath="
-                        #$output "/lib/mutter-12")
+                        #$output "/lib/mutter-13")
          ;; Disable systemd support.
          "-Dsystemd=false"
          ;; Don't install tests.
@@ -7937,8 +7937,8 @@ (define-public mutter
            python-dbus
            python-dbusmock))
     (propagated-inputs
-     (list gsettings-desktop-schemas      ;required by libmutter-12.pc
-           ;; mutter-clutter-12.pc and mutter-cogl-12.pc refer to these:
+     (list gsettings-desktop-schemas      ;required by libmutter-13.pc
+           ;; mutter-clutter-13.pc and mutter-cogl-13.pc refer to these:
            at-spi2-core
            cairo
            eudev
@@ -7966,6 +7966,7 @@ (define-public mutter
            gnome-settings-daemon
            graphene
            libcanberra
+           libei
            libgudev
            libice
            libsm
-- 
2.41.0